@@ -30,7 +30,7 @@ BOOL cmd_jobs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     char buf[BUFSIZ];
     int i;
-    for(i=0; i<vector_size(gJobs); i++) {
+    for(i=0; i<vector_count(gJobs); i++) {
         sObject* job = vector_item(gJobs, i);
         int size = snprintf(buf, BUFSIZ, "[%d] name: %s pid&pgrp: %d", i+1, SJOB(job).mName, SJOB(job).mPGroup);
         if(!fd_write(nextout, buf, size)) {
@@ -46,7 +46,7 @@ BOOL cmd_jobs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
     }
 
-    if(vector_size(gJobs) == 0) {
+    if(vector_count(gJobs) == 0) {
         runinfo->mRCode = 1;
     }
     else {
@@ -87,7 +87,7 @@ BOOL cmd_exit(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         runinfo->mRCode = RCODE_EXIT;
     }
     else {
-        if(vector_size(gJobs) > 0) {
+        if(vector_count(gJobs) > 0) {
             err_msg("jobs exist", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
             return FALSE;
         }
@@ -120,6 +120,7 @@ BOOL cmd_while(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(!run(command->mBlocks[1], nextin, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
                 if(rcode == RCODE_BREAK) {
                     rcode = 0;
+                    break;
                 }
                 else {
                     runinfo->mRCode = rcode;
@@ -254,10 +255,10 @@ BOOL cmd_stackframe(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
     char buf[BUFSIZ];
 
-    hash_it* it = hash_loop_begin(SFUN(runinfo->mRunningObject).mLocalObjects);
+    uobject_it* it = uobject_loop_begin(SFUN(runinfo->mRunningObject).mLocalObjects);
     while(it) {
-        sObject* object2 = hash_loop_item(it);
-        char* key = hash_loop_key(it);
+        sObject* object2 = uobject_loop_item(it);
+        char* key = uobject_loop_key(it);
 
         char*obj_kind[16] = {
             NULL, "var", "array", "hash", "list", "native function", "block", "file dicriptor", "job", "object", "memchecker", "function", "class", "external program", "completion", "external object"
@@ -270,10 +271,10 @@ BOOL cmd_stackframe(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             return FALSE;
         }
 
-        it = hash_loop_next(it);
+        it = uobject_loop_next(it);
     }
 
-    if(hash_count(SFUN(runinfo->mRunningObject).mLocalObjects) == 0) {
+    if(uobject_count(SFUN(runinfo->mRunningObject).mLocalObjects) == 0) {
         runinfo->mRCode = 1;
     }
     else {
@@ -394,7 +395,7 @@ BOOL cmd_sweep(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             char* var_name = command->mArgsRuntime[i];
             sObject* current_object = runinfo->mCurrentObject;
 
-            sObject* item = hash_item(current_object, var_name);
+            sObject* item = uobject_item(current_object, var_name);
 
             if(item && item->mUserObject) {
                 if(item != gCurrentObject || strcmp(var_name, SUOBJECT(item).mName) != 0) {
@@ -672,9 +673,9 @@ static BOOL xyzsh_seek_external_programs(char* path, sObject* sys, char* sname,
                 && strcmp(entry->d_name, "..") != 0
                 &&
                 (stat_.st_mode & S_IXUSR ||stat_.st_mode & S_IXGRP||stat_.st_mode & S_IXOTH)
-                && hash_item(sys, entry->d_name) == NULL)
+                && uobject_item(sys, entry->d_name) == NULL)
             {
-                hash_put(sys, entry->d_name, EXTERNAL_NEW_GC(path2, TRUE));
+                uobject_put(sys, entry->d_name, EXTPROG_NEW_GC(path2, TRUE));
             }
         }
 
@@ -699,7 +700,7 @@ BOOL xyzsh_rehash(char* sname, int sline)
     }
 
     sObject* sys = UOBJECT_NEW_GC(8, gRootObject, "sys", FALSE);
-    hash_put(gRootObject, "sys", sys);
+    uobject_put(gRootObject, "sys", sys);
     uobject_init(sys);
 
     char buf[PATH_MAX+1];
@@ -797,7 +798,7 @@ BOOL cmd_prompt(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     sCommand* command = runinfo->mCommand;
     if(command->mBlocksNum == 1) {
         gPrompt = block_clone_gc(command->mBlocks[0], T_BLOCK, FALSE);
-        hash_put(gxyzshObject, "_prompt", gPrompt);
+        uobject_put(gxyzshObject, "_prompt", gPrompt);
         runinfo->mRCode = 0;
     }
 
@@ -812,7 +813,7 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(sCommand_option_item(command, "-number")) {
         if(SFUN(fun).mArgBlocks) {
             char buf[32];
-            int size = snprintf(buf, 32, "%d\n", vector_size(SFUN(fun).mArgBlocks));
+            int size = snprintf(buf, 32, "%d\n", vector_count(SFUN(fun).mArgBlocks));
 
             if(!fd_write(nextout, buf, size))
             {
@@ -833,7 +834,7 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             block_num = 0;
         }
 
-        if(SFUN(fun).mArgBlocks && block_num < vector_size(SFUN(fun).mArgBlocks)) {
+        if(SFUN(fun).mArgBlocks && block_num < vector_count(SFUN(fun).mArgBlocks)) {
             sObject* block = vector_item(SFUN(fun).mArgBlocks, block_num);
             sObject* fun = fun_clone_from_stack_block_stack(block, NULL);
 
@@ -853,7 +854,7 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             block_num = 0;
         }
 
-        if(SFUN(fun).mArgBlocks && block_num < vector_size(SFUN(fun).mArgBlocks)) {
+        if(SFUN(fun).mArgBlocks && block_num < vector_count(SFUN(fun).mArgBlocks)) {
             sObject* block = vector_item(SFUN(fun).mArgBlocks, block_num);
 
             if(!fd_write(nextout, SBLOCK(block).mSource, strlen(SBLOCK(block).mSource)))
@@ -869,3 +870,85 @@ BOOL cmd_block(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     return TRUE;
 }
+
+BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
+{
+    sCommand* command = runinfo->mCommand;
+
+    if(sCommand_option_item(command, "-byte")) {
+        gKanjiCode = kByte;
+        runinfo->mRCode = 0;
+    }
+    else if(sCommand_option_item(command, "-utf8")) {
+        gKanjiCode = kUtf8;
+        runinfo->mRCode = 0;
+    }
+    else if(sCommand_option_item(command, "-sjis")) {
+        gKanjiCode = kSjis;
+        runinfo->mRCode = 0;
+    }
+    else if(sCommand_option_item(command, "-eucjp")) {
+        gKanjiCode = kEucjp;
+        runinfo->mRCode = 0;
+    }
+    else {
+        if(gKanjiCode == kUtf8) {
+            if(!fd_write(nextout, "utf8", 4)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+            if(!fd_write(nextout, "\n", 1)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+
+            runinfo->mRCode = 0;
+        }
+        else if(gKanjiCode == kByte) {
+            if(!fd_write(nextout, "byte", 4)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+            if(!fd_write(nextout, "\n", 1)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+
+            runinfo->mRCode = 0;
+        }
+        else if(gKanjiCode == kSjis) {
+            if(!fd_write(nextout, "sjis", 4)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+            if(!fd_write(nextout, "\n", 1)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+
+            runinfo->mRCode = 0;
+        }
+        else if(gKanjiCode == kEucjp) {
+            if(!fd_write(nextout, "eucjp", 5)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+            if(!fd_write(nextout, "\n", 1)) {
+                err_msg("interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
+                return FALSE;
+            }
+
+            runinfo->mRCode = 0;
+        }
+    }
+
+    return TRUE;
+}
