@@ -126,7 +126,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     if(runinfo->mFilter) {
         fd_split(nextin, lf);
 
-        if(vector_size(SFD(nextin).fdbuf.mLines) > 0) {
+        if(vector_count(SFD(nextin).fdbuf.mLines) > 0) {
 #if !defined(__FREEBSD__)
             msave_screen();
 #endif
@@ -136,13 +136,13 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             const int maxx = mgetmaxx();
             const int maxy = mgetmaxy();
 
-            int* markfiles = MALLOC(sizeof(int)*vector_size(SFD(nextin).fdbuf.mLines));
-            memset(markfiles, 0, sizeof(int)*vector_size(SFD(nextin).fdbuf.mLines));
+            int* markfiles = MALLOC(sizeof(int)*vector_count(SFD(nextin).fdbuf.mLines));
+            memset(markfiles, 0, sizeof(int)*vector_count(SFD(nextin).fdbuf.mLines));
 
             static int scrolltop = 0;
             static int cursor = 0;
 
-            if(!sCommand_option_item(command, "-prereserve-position")) {
+            if(!sCommand_option_item(command, "-preserve-position")) {
                 scrolltop = 0;
                 cursor = 0;
             }
@@ -150,8 +150,8 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(cursor < 0) {
                 cursor = 0;
             }
-            if(cursor >= vector_size(SFD(nextin).fdbuf.mLines)) {
-                cursor = vector_size(SFD(nextin).fdbuf.mLines)-1;
+            if(cursor >= vector_count(SFD(nextin).fdbuf.mLines)) {
+                cursor = vector_count(SFD(nextin).fdbuf.mLines)-1;
                 if(cursor < 0) cursor = 0;
             }
             if(cursor < scrolltop) {
@@ -176,7 +176,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 mclear();
                 int n = scrolltop;
                 int y = 0;
-                while(y < maxy && n < vector_size(SFD(nextin).fdbuf.mLines)) {
+                while(y < maxy && n < vector_count(SFD(nextin).fdbuf.mLines)) {
                     int attrs = 0;
                     if(n == cursor) {
                         attrs |= kCAReverse;
@@ -244,7 +244,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 }
                 else if(key == 'a' && multiple) {
                     int i;
-                    for(i=0; i<vector_size(SFD(nextin).fdbuf.mLines); i++) {
+                    for(i=0; i<vector_count(SFD(nextin).fdbuf.mLines); i++) {
                         markfiles[i] = !markfiles[i];
                     }
                 }
@@ -256,7 +256,7 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     if(multiple) {
                         BOOL flg_mark = FALSE;
                         int k;
-                        for(k=0; k<vector_size(SFD(nextin).fdbuf.mLines); k++) {
+                        for(k=0; k<vector_count(SFD(nextin).fdbuf.mLines); k++) {
                             if(markfiles[k]) {
                                 char* str = vector_item(SFD(nextin).fdbuf.mLines, k);
                                 if(!fd_write(nextout,str, strlen(str))) {
@@ -301,8 +301,8 @@ BOOL cmd_selector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 if(cursor < 0) {
                     cursor = 0;
                 }
-                if(cursor >= vector_size(SFD(nextin).fdbuf.mLines)) {
-                    cursor = vector_size(SFD(nextin).fdbuf.mLines)-1;
+                if(cursor >= vector_count(SFD(nextin).fdbuf.mLines)) {
+                    cursor = vector_count(SFD(nextin).fdbuf.mLines)-1;
                     if(cursor < 0) cursor = 0;
                 }
                 if(cursor >= n) {
@@ -417,8 +417,8 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         const int maxx = mgetmaxx();
         const int maxy = mgetmaxy();
 
-        int* markfiles = MALLOC(sizeof(int)*vector_size(SFD(nextin2).fdbuf.mLines));
-        memset(markfiles, 0, sizeof(int)*vector_size(SFD(nextin2).fdbuf.mLines));
+        int* markfiles = MALLOC(sizeof(int)*vector_count(SFD(nextin2).fdbuf.mLines));
+        memset(markfiles, 0, sizeof(int)*vector_count(SFD(nextin2).fdbuf.mLines));
 
         static int scrolltop = 0;
         static int cursor = 0;
@@ -431,8 +431,8 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         if(cursor < 0) {
             cursor = 0;
         }
-        if(cursor >= vector_size(SFD(nextin2).fdbuf.mLines)) {
-            cursor = vector_size(SFD(nextin2).fdbuf.mLines)-1;
+        if(cursor >= vector_count(SFD(nextin2).fdbuf.mLines)) {
+            cursor = vector_count(SFD(nextin2).fdbuf.mLines)-1;
             if(cursor < 0) cursor = 0;
         }
         if(cursor < scrolltop) {
@@ -457,7 +457,7 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             mclear();
             int n = scrolltop;
             int y = 0;
-            while(y < maxy && n < vector_size(SFD(nextin2).fdbuf.mLines)) {
+            while(y < maxy && n < vector_count(SFD(nextin2).fdbuf.mLines)) {
                 int attrs = 0;
                 if(n == cursor) {
                     attrs |= kCAReverse;
@@ -543,8 +543,8 @@ BOOL cmd_p(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(cursor < 0) {
                 cursor = 0;
             }
-            if(cursor >= vector_size(SFD(nextin2).fdbuf.mLines)) {
-                cursor = vector_size(SFD(nextin2).fdbuf.mLines)-1;
+            if(cursor >= vector_count(SFD(nextin2).fdbuf.mLines)) {
+                cursor = vector_count(SFD(nextin2).fdbuf.mLines)-1;
                 if(cursor < 0) cursor = 0;
             }
             if(cursor >= n) {
@@ -969,7 +969,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
     sObject* mark_files = VECTOR_NEW_STACK(10);
 
-    if(vector_size(v) > 0) {
+    if(vector_count(v) > 0) {
         msave_ttysettings();       // 端末の設定の保存
 #if !defined(__FREEBSD__)
         msave_screen();
@@ -987,7 +987,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             int page = cursor/((maxy-1)*4);
             int n = page*4*(maxy-1);
-            while(n < page*4*(maxy-1)+(maxy-1)*4 && n < vector_size(v)) {
+            while(n < page*4*(maxy-1)+(maxy-1)*4 && n < vector_count(v)) {
                 sFile* file = vector_item(v, n);
 
                 int attrs = 0;
@@ -1012,7 +1012,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                 BOOL marked = FALSE;
                 int i;
-                for(i=0; i<vector_size(mark_files); i++) {
+                for(i=0; i<vector_count(mark_files); i++) {
                     sObject* mark_file = vector_item(mark_files, i);
 
                     if(strcmp(string_c_str(mark_file), full_path) == 0) {
@@ -1070,7 +1070,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 xstrncat(cursor_path, string_c_str(cursor_file->mName), PATH_MAX);
 
                 int i;
-                for(i=0; i<vector_size(mark_files); i++) {
+                for(i=0; i<vector_count(mark_files); i++) {
                     sObject* mfile = vector_item(mark_files, i);
 
                     if(strcmp(string_c_str(mfile), cursor_path) == 0) {
@@ -1093,7 +1093,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 xstrncpy(current_dir, "/", PATH_MAX);
 
                 int i;
-                for(i=0; i<vector_size(v); i++) {
+                for(i=0; i<vector_count(v); i++) {
                     sFile_delete(vector_item(v, i));
                 }
                 vector_clear(v);
@@ -1112,7 +1112,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 #endif
                 mrestore_ttysettings();    // 端末の設定の復帰
                 int i;
-                for(i=0; i<vector_size(v); i++) {
+                for(i=0; i<vector_count(v); i++) {
                     sFile_delete(vector_item(v, i));
                 }
                 return FALSE;
@@ -1133,7 +1133,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         }
 
                         int i;
-                        for(i=0; i<vector_size(v); i++) {
+                        for(i=0; i<vector_count(v); i++) {
                             sFile_delete(vector_item(v, i));
                         }
                         vector_clear(v);
@@ -1149,7 +1149,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 xstrncpy(current_dir, parent_path, PATH_MAX);
 
                 int i;
-                for(i=0; i<vector_size(v); i++) {
+                for(i=0; i<vector_count(v); i++) {
                     sFile_delete(vector_item(v, i));
                 }
                 vector_clear(v);
@@ -1162,8 +1162,8 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             if(cursor < 0) {
                 cursor = 0;
             }
-            if(cursor >= vector_size(v)) {
-                cursor = vector_size(v)-1;
+            if(cursor >= vector_count(v)) {
+                cursor = vector_count(v)-1;
             }
         }
 
@@ -1175,7 +1175,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 #endif
         mrestore_ttysettings();    // 端末の設定の復帰
 
-        if(vector_size(mark_files) == 0) {
+        if(vector_count(mark_files) == 0) {
             sFile* cursor_file = vector_item(v, cursor);
 
             /// 現在のカレントディレクトリのパスなら
@@ -1199,7 +1199,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     int i;
-                    for(i=0; i<vector_size(v); i++) {
+                    for(i=0; i<vector_count(v); i++) {
                         sFile_delete(vector_item(v, i));
                     }
                     return FALSE;
@@ -1211,7 +1211,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                 {
                     err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                     int i;
-                    for(i=0; i<vector_size(v); i++) {
+                    for(i=0; i<vector_count(v); i++) {
                         sFile_delete(vector_item(v, i));
                     }
                     return FALSE;
@@ -1220,7 +1220,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         }
         else {
             int j;
-            for(j=0; j<vector_size(mark_files); j++) {
+            for(j=0; j<vector_count(mark_files); j++) {
                 char full_path[PATH_MAX+1];
                 xstrncpy(full_path
                     , string_c_str((sObject*)vector_item(mark_files, j))
@@ -1238,7 +1238,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     {
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         int i;
-                        for(i=0; i<vector_size(v); i++) {
+                        for(i=0; i<vector_count(v); i++) {
                             sFile_delete(vector_item(v, i));
                         }
                         return FALSE;
@@ -1250,7 +1250,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     {
                         err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
                         int i;
-                        for(i=0; i<vector_size(v); i++) {
+                        for(i=0; i<vector_count(v); i++) {
                             sFile_delete(vector_item(v, i));
                         }
                         return FALSE;
@@ -1261,7 +1261,7 @@ BOOL cmd_fselector(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
     }
 
     int i;
-    for(i=0; i<vector_size(v); i++) {
+    for(i=0; i<vector_count(v); i++) {
         sFile_delete(vector_item(v, i));
     }
 
