@@ -122,10 +122,31 @@ static BOOL read_env(char** p, sBuf* buf, char* sname, int* sline, BOOL expand_q
 {
     (*p)++;
 
+    enum eLineField lf = kLF;
+
     BOOL double_dollar;
     if(**p == '$') {
         (*p)++;
         double_dollar = TRUE;
+
+        if(*(*p+1) == '(') {
+            if(**p == 'a') {
+                (*p)++;
+                lf = kBel;
+            }
+            else if(**p == 'm') {
+                (*p)++;
+                lf = kCR;
+            }
+            else if(**p == 'w') {
+                (*p)++;
+                lf = kCRLF;
+            }
+            else if(**p == 'u') {
+                (*p)++;
+                lf = kLF;
+            }
+        }
     }
     else {
         double_dollar = FALSE;
@@ -136,7 +157,7 @@ static BOOL read_env(char** p, sBuf* buf, char* sname, int* sline, BOOL expand_q
 
         sObject* block2 = BLOCK_NEW_STACK();
         if(!block_parse(p, sname, sline, block2, current_object)) {
-            sCommand_add_env_block(command, block2);
+            sCommand_add_env_block(command, block2, double_dollar, lf);
             SBLOCK(block).mCompletionFlags |= COMPLETION_FLAGS_ENV_BLOCK;
             SBLOCK(block).mCompletionFlags |= command->mEnvsNum & 0xFF;
             return FALSE;
@@ -150,7 +171,7 @@ static BOOL read_env(char** p, sBuf* buf, char* sname, int* sline, BOOL expand_q
         add_str_to_buf(buf, buf2);
         add_char_to_buf(buf, PARSER_MAGIC_NUMBER_ENV);
 
-        sCommand_add_env_block(command, block2);
+        sCommand_add_env_block(command, block2, double_dollar, lf);
     }
     else {
         SBLOCK(block).mCompletionFlags |= COMPLETION_FLAGS_ENV;
@@ -844,7 +865,7 @@ static BOOL read_command(char** p, sCommand* command, sStatment* statment, sObje
                         if(object && TYPE(object) == T_UOBJECT) {
                             int i;
                             for(i=1; i<command->mMessagesNum; i++) {
-                                object = hash_item(object, command->mMessages[i]);
+                                object = uobject_item(object, command->mMessages[i]);
 
                                 if(object == NULL || TYPE(object) != T_UOBJECT) {
                                     break;
@@ -906,6 +927,7 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
     /// a global pipe ///
     if(**p == '|' && *(*p+1) == '>') {
         (*p)+=2;
+
         skip_spaces(p);
 
         statment->mFlags |= STATMENT_GLOBALPIPEIN;
@@ -914,9 +936,19 @@ static BOOL read_statment(char**p, sStatment* statment, sObject* block, char* sn
     /// a context pipe ///
     else if(**p == '|' && *(*p+1) != '|') {
         (*p)++;
+
+        char buf[16];
+        char* p2 = buf;
+        while(**p == '-' || **p >= '0' && **p <= '9') {
+            *p2++ = **p;
+            (*p)++;
+        }
+        *p2 = 0;
+
         skip_spaces(p);
 
         statment->mFlags |= STATMENT_CONTEXTPIPE;
+        statment->mFlags |= atoi(buf) & STATMENT_CONTEXTPIPE_NUMBER;
         SBLOCK(block).mCompletionFlags |= COMPLETION_FLAGS_STATMENT_HEAD;
     }
 
